==> lxqt-panel-0.9.0.tar.xz: lxqt-panel-0.9.0/plugin-cpuload/lxqtcpuloadplugin.cpp <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXDE-Qt - a lightweight, Qt based, desktop toolset
 * http://razor-qt.org
 *
 * Copyright: 2013 Razor team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */


#include "lxqtcpuloadplugin.h"
#include "lxqtcpuload.h"
#include "lxqtcpuloadconfiguration.h"

#include <QVBoxLayout>

LxQtCpuLoadPlugin::LxQtCpuLoadPlugin(const ILxQtPanelPluginStartupInfo &startupInfo):
    QObject(),
    ILxQtPanelPlugin(startupInfo)
{
    mWidget = new QWidget();
    mContent = new LxQtCpuLoad(this, mWidget);
    QVBoxLayout *layout = new QVBoxLayout(mWidget);
    layout->setContentsMargins(0, 0, 0, 0);
    layout->setSpacing(0);
    layout->addWidget(mContent);
    layout->setStretchFactor(mContent, 1);
}

LxQtCpuLoadPlugin::~LxQtCpuLoadPlugin()
{
    delete mWidget;
}

QWidget *LxQtCpuLoadPlugin::widget()
{
    return mWidget;
}

QDialog *LxQtCpuLoadPlugin::configureDialog()
{
    return new LxQtCpuLoadConfiguration(settings(), mContent);
}

void LxQtCpuLoadPlugin::settingsChanged()
{
    mContent->settingsChanged();
}

==> lxqt-panel_0.12.0.orig.tar.xz: lxqt-panel-0.12.0/plugin-cpuload/lxqtcpuloadplugin.cpp <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXDE-Qt - a lightweight, Qt based, desktop toolset
 * http://razor-qt.org
 *
 * Copyright: 2013 Razor team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */


#include "lxqtcpuloadplugin.h"
#include "lxqtcpuload.h"
#include "lxqtcpuloadconfiguration.h"

#include <QVBoxLayout>

LXQtCpuLoadPlugin::LXQtCpuLoadPlugin(const ILXQtPanelPluginStartupInfo &startupInfo):
    QObject(),
    ILXQtPanelPlugin(startupInfo)
{
    mWidget = new QWidget();
    mContent = new LXQtCpuLoad(this, mWidget);
    QVBoxLayout *layout = new QVBoxLayout(mWidget);
    layout->setContentsMargins(0, 0, 0, 0);
    layout->setSpacing(0);
    layout->addWidget(mContent);
    layout->setStretchFactor(mContent, 1);
}

LXQtCpuLoadPlugin::~LXQtCpuLoadPlugin()
{
    delete mWidget;
}

QWidget *LXQtCpuLoadPlugin::widget()
{
    return mWidget;
}

QDialog *LXQtCpuLoadPlugin::configureDialog()
{
    return new LXQtCpuLoadConfiguration(settings());
}

void LXQtCpuLoadPlugin::settingsChanged()
{
    mContent->settingsChanged();
}
